@@ -125,8 +125,8 @@ class Activator(Save):
                     (Activity.tableName == entity.__tablename__) & \
                     (Activity.data[id_key].astext.cast(BigInteger) == entity.id)
                 ).order_by(desc(Activity.dateCreated)).limit(1).first()
-                if not last_activity and entity.__class__.__name__ == 'User':
-                    print('last_activity not found because activity not work with user for now...')
+                if not last_activity:
+                    logger.debug('last_activity not found for {} {}...'.format(entity.__class__.__name__, entity.id))
                     continue
                 last_activity.uuid = entity.activityUuid
                 activities.append(last_activity)
